[![Python Version](https://img.shields.io/pypi/pyversions/ethology.svg)](https://pypi.org/project/ethology)
[![PyPI Version](https://img.shields.io/pypi/v/ethology.svg)](https://pypi.org/project/ethology)
[![License](https://img.shields.io/badge/License-BSD_3--Clause-orange.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![CI](https://img.shields.io/github/actions/workflow/status/neuroinformatics-unit/ethology/test_and_deploy.yml?label=CI)](https://github.com/neuroinformatics-unit/ethology/actions)
[![Code style: Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/format.json)](https://github.com/astral-sh/ruff)
[![codecov](https://codecov.io/gh/neuroinformatics-unit/ethology/branch/main/graph/badge.svg?token=P8CCH3TI8K)](https://codecov.io/gh/neuroinformatics-unit/ethology)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/neuroinformatics-unit/ethology/main.svg)](https://results.pre-commit.ci/latest/github/neuroinformatics-unit/ethology/main)

# ethology

Mix-and-match computer vision tools for your animal behaviour analysis.

## Quick install

Create a conda environment and install the package
```sh
conda create -n ethology-env python=3.12 -y
conda activate ethology-env
pip install ethology
```

For more information please check our [documentation](https://ethology.neuroinformatics.dev).

Contributions and feature requests are more than welcome! Have a look at our [Contributing guidelines](https://ethology.neuroinformatics.dev/community/contributing.html) and feel to [open an issue](https://github.com/neuroinformatics-unit/ethology/issues) to report a bug or request a new feature.
